diff src/plugins/plugin_xep_0095.py @ 391:c34fd9d6242e

spelling
author Goffi <goffi@goffi.org>
date Thu, 29 Sep 2011 14:59:14 +0200
parents 41fdaeb005bc
children 8f3551ceee17
line wrap: on
line diff
--- a/src/plugins/plugin_xep_0095.py	Thu Sep 29 14:43:33 2011 +0200
+++ b/src/plugins/plugin_xep_0095.py	Thu Sep 29 14:59:14 2011 +0200
@@ -109,11 +109,11 @@
         self.sendError(id, to_jid, 400, 'cancel', profile=profile)
     
     def sendFailedError(self, id, to_jid, profile):
         """Helper method to send when we transfert failed
         @param id: IQ id
         @param to_jid: recipient
         @param profile: %(doc_profile)s"""
-        self.sendError(id, to_jid, 500, 'cancel', {'custom':'failed'}, profile=profile) #as there is no error code for failed transfert, we use 500 (undefined-condition)
+        self.sendError(id, to_jid, 500, 'cancel', {'custom':'failed'}, profile=profile) #as there is no error code for failed transfer, we use 500 (undefined-condition)
     
     def sendError(self, id, to_jid, err_code, err_type='cancel', data={}, profile='@NONE@'):
         """Send IQ error as a result
@@ -109,11 +109,11 @@
     
     def sendFailedError(self, id, to_jid, profile):
-        """Helper method to send when we transfert failed
+        """Helper method to send when we transfer failed
         @param id: IQ id
         @param to_jid: recipient